/*
** Module   : ButtonImageDefinition.java
** Abstract : stores button specific image definition
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 EVL 20150206 Created initial version.
*/

package com.goldencode.p2j.ui;

import java.io.*;

/**
 * This works like a public data structure to store all image related options for up or down or
 * insensitive state of the button widget.  Used to unify option access. 
 */
public class ButtonImageDefinition
implements Externalizable
{
   /** X offset in pixel units inside the image data to start drawing image. */
   public int offsetX = -1;
   
   /** Y offset in pixel units inside the image data to start drawing image. */
   public int offsetY = -1;
   
   /** Row offset in character units inside the image data to start drawing image. */
   public int offsetRow = 0;
   
   /** Column offset in character units inside the image data to start drawing image. */
   public int offsetCol = 0;

   /** Image width in pixel units. */   
   public int widthPixels = 0;
   
   /** Image width in character units. */   
   public int widthChars = 0;
   
   /** Image height in pixel units. */   
   public int heightPixels = 0;
   
   /** Image height in character units. */   
   public int heightChars = 0;

   /** Button image file name. */
   public String name = null;

   /**
    * Default constructor (only used in deserialization).
    */
   public ButtonImageDefinition()
   {
   }

   /**
    * Replacement for the default object reading method. The latest state is read from the input
    * source.
    * 
    * @param    in
    *           The input source from which fields will be restored.
    *
    * @throws   IOException
    *           In case of I/O errors.
    * @throws   ClassNotFoundException
    *           If payload can't be instantiated.
    */
   @Override
   public void readExternal(ObjectInput in)
   throws IOException,
          ClassNotFoundException
   {
      offsetX      = in.readInt();
      offsetY      = in.readInt();
      offsetRow    = in.readInt();
      offsetCol    = in.readInt();
      widthPixels  = in.readInt();
      widthChars   = in.readInt();
      heightPixels = in.readInt();
      heightChars  = in.readInt();
      name         = (String) in.readObject();
   }

   /**
    * Replacement for the default object writing method. The latest state is written to the output
    * destination.
    * 
    * @param    out
    *           The output destination to which fields will be saved.
    *
    * @throws   IOException
    *           In case of I/O errors.
    */
   @Override
   public void writeExternal(ObjectOutput out)
   throws IOException
   {
      out.writeInt(offsetX);
      out.writeInt(offsetY);
      out.writeInt(offsetRow);
      out.writeInt(offsetCol);
      out.writeInt(widthPixels);
      out.writeInt(widthChars);
      out.writeInt(heightPixels);
      out.writeInt(heightChars);
      out.writeObject(name);
   }
}
